<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * X-Cart
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the software license agreement
 * that is bundled with this package in the file LICENSE.txt.
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to licensing@x-cart.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not modify this file if you wish to upgrade X-Cart to newer versions
 * in the future. If you wish to customize X-Cart for your needs please
 * refer to http://www.x-cart.com/ for more information.
 *
 * @category  X-Cart 5
 * @author    Qualiteam software Ltd <info@x-cart.com>
 * @copyright Copyright (c) 2011-2016 Qualiteam software Ltd <info@x-cart.com>. All rights reserved
 * @link      http://www.x-cart.com/
 */

namespace XLite\Module\QSL\CallForPrice\View\Button\Product;

/**
 * Decorated Express Checkout button.
 *
 * @LC_Dependencies ("CDev\Paypal")
 */
class ExpressCheckout extends \XLite\Module\CDev\Paypal\View\Button\Product\ExpressCheckout
    implements \XLite\Base\IDecorator
{
    /**
     * Widget parameters
     */
    const PARAM_PRODUCT_ID = 'product_id';

    /**
     * Product model cache
     *
     * @var \XLite\Model\Product | null
     */
    protected $product;

    /**
     * Return the specific widget service name to make it visible as specific CSS class
     *
     * @return null|string
     */
    public function getFingerprint()
    {
        return 'widget-fingerprint-paypal-now-button';
    }

    /**
     * Define widget parameters.
     *
     * @return void
     */
    protected function defineWidgetParams()
    {
        parent::defineWidgetParams();

        $this->widgetParams += array(
            static::PARAM_PRODUCT_ID    => new \XLite\Model\WidgetParam\Int('Product ID', 0),
        );
    }

    /**
     * Define so called "request" parameters
     *
     * @return void
     */
    protected function defineRequestParams()
    {
        parent::defineRequestParams();

        $this->requestParams[] = static::PARAM_PRODUCT_ID;
    }

    /**
     * Get CSS class name
     *
     * @return string
     */
    protected function getClass()
    {
        return parent::getClass() . ' ' . $this->getFingerprint();
    }

    /**
     * Get the widget template.
     *
     * @return string
     */
    protected function getTemplate()
    {
        return $this->isWidgetEmpty() ? $this->getEmptyWidgetTemplate() : parent::getTemplate();
    }

    /**
     * Check if the widget should be shown as empty (required for WidgetsCollection).
     *
     * @return boolean
     */
    protected function isWidgetEmpty()
    {
        return $this->isCallForPrice();
    }

    /**
     * Get path to the template that should replace the default widget template when it is empty.
     *
     * @return string
     */
    protected function getEmptyWidgetTemplate()
    {
        return 'modules/QSL/CallForPrice/widgets_collection/empty_widget.tpl';
    }
    
    /**
     * Returns the product model.
     *
     * @return \XLite\Model\Product
     */
    protected function getProduct()
    {
        if (is_null($this->product)) {
            $id = $this->getParam(self::PARAM_PRODUCT_ID);
            $this->product = $id
                ? \XLite\Core\Database::getRepo('XLite\Model\Product')->find($id)
                : $this->getProductFromController();
        }

        return $this->product;
    }
    
    /**
     * Retrieve the product model from the controller class.
     * 
     * @return \XLite\Model\Product
     */
    protected function getProductFromController()
    {
        $controller = \XLite::getController();
        $value = method_exists($controller, 'getProduct') ? $controller->getProduct() : null;

        return $value;
    }

    /**
     * Check if it is a Call For Price item.
     *
     * @return boolean
     */
    protected function isCallForPrice()
    {
        return $this->getProduct()->isCallForPrice();
    }
}