<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * X-Cart
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the software license agreement
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.x-cart.com/license-agreement.html
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to licensing@x-cart.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not modify this file if you wish to upgrade X-Cart to newer versions
 * in the future. If you wish to customize X-Cart for your needs please
 * refer to http://www.x-cart.com/ for more information.
 *
 * @category  X-Cart 5
 * @author    Qualiteam software Ltd <info@x-cart.com>
 * @copyright Copyright (c) 2011-2015 Qualiteam software Ltd <info@x-cart.com>. All rights reserved
 * @license   http://www.x-cart.com/license-agreement.html X-Cart 5 License Agreement
 * @link      http://www.x-cart.com/
 */

namespace XLite\Module\CDev\SimpleCMS\Model\Menu;

/**
 * Menu quick flags
 *
 * @Entity (repositoryClass="\XLite\Module\CDev\SimpleCMS\Model\Repo\Menu\QuickFlags")
 * @Table  (name="menu_quick_flags")
 */
class QuickFlags extends \XLite\Model\AEntity
{
    /**
     * Doctrine ID
     *
     * @var integer
     *
     * @Id
     * @GeneratedValue (strategy="AUTO")
     * @Column         (type="integer")
     */
    protected $id;

    /**
     * Total number of submenus
     *
     * @var integer
     *
     * @Column (type="integer")
     */
    protected $submenus_count_all = 0;

    /**
     * Number of enabled submenus
     *
     * @var integer
     *
     * @Column (type="integer")
     */
    protected $submenus_count_enabled = 0;

    /**
     * Relation to a menu entity
     *
     * @var \XLite\Module\CDev\SimpleCMS\Model\Menu
     *
     * @OneToOne   (targetEntity="XLite\Module\CDev\SimpleCMS\Model\Menu", inversedBy="quickFlags")
     * @JoinColumn (name="menu_id", referencedColumnName="id")
     */
    protected $menu;

    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set submenus_count_all
     *
     * @param integer $submenusCountAll
     * @return QuickFlags
     */
    public function setSubmenusCountAll($submenusCountAll)
    {
        $this->submenus_count_all = $submenusCountAll;
        return $this;
    }

    /**
     * Get submenus_count_all
     *
     * @return integer 
     */
    public function getSubmenusCountAll()
    {
        return $this->submenus_count_all;
    }

    /**
     * Set submenus_count_enabled
     *
     * @param integer $submenusCountEnabled
     * @return QuickFlags
     */
    public function setSubmenusCountEnabled($submenusCountEnabled)
    {
        $this->submenus_count_enabled = $submenusCountEnabled;
        return $this;
    }

    /**
     * Get submenus_count_enabled
     *
     * @return integer 
     */
    public function getSubmenusCountEnabled()
    {
        return $this->submenus_count_enabled;
    }

    /**
     * Set menu
     *
     * @param XLite\Module\CDev\SimpleCMS\Model\Menu $menu
     * @return QuickFlags
     */
    public function setMenu(\XLite\Module\CDev\SimpleCMS\Model\Menu $menu = null)
    {
        $this->menu = $menu;
        return $this;
    }

    /**
     * Get menu
     *
     * @return XLite\Module\CDev\SimpleCMS\Model\Menu 
     */
    public function getMenu()
    {
        return $this->menu;
    }
}