<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * X-Cart
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the software license agreement
 * that is bundled with this package in the file LICENSE.txt.
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to licensing@x-cart.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not modify this file if you wish to upgrade X-Cart to newer versions
 * in the future. If you wish to customize X-Cart for your needs please
 * refer to http://www.x-cart.com/ for more information.
 *
 * @category  X-Cart 5
 * @author    Qualiteam software Ltd <info@x-cart.com>
 * @copyright Copyright (c) 2011-2013 Qualiteam software Ltd <info@x-cart.com>. All rights reserved
 * @link      http://www.x-cart.com/
 */

namespace XLite\Module\QSL\CallForPrice\Model;

/**
 * Decorated product model
 * @MappedSuperClass
 */
abstract class Product extends \XLite\Module\CDev\FeaturedProducts\Model\Product implements \XLite\Base\IDecorator
{
    /**
     * Whether Call For Price should be shown instead of Add to Cart, or not.
     *
     * @var boolean
     *
     * @Column (type="boolean", nullable=true)
     */
    protected $callForPrice = false;

    /**
     * Check if the Call For Price feature is enabled for the product.
     *
     * @return boolean
     */
    public function isCallForPrice()
    {
        return $this->callForPrice;
    }

    /**
     * Set callForPrice
     *
     * @param boolean $callForPrice
     * @return Product
     */
    public function setCallForPrice($callForPrice)
    {
        $this->callForPrice = $callForPrice;
        return $this;
    }

    /**
     * Get callForPrice
     *
     * @return boolean 
     */
    public function getCallForPrice()
    {
        return $this->callForPrice;
    }
}