<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * X-Cart
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the software license agreement
 * that is bundled with this package in the file LICENSE.txt.
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to licensing@x-cart.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not modify this file if you wish to upgrade X-Cart to newer versions
 * in the future. If you wish to customize X-Cart for your needs please
 * refer to http://www.x-cart.com/ for more information.
 *
 * @category  X-Cart 5
 * @author    Qualiteam software Ltd <info@x-cart.com>
 * @copyright Copyright (c) 2011-2013 Qualiteam software Ltd <info@x-cart.com>. All rights reserved
 * @link      http://www.x-cart.com/
 */

namespace XLite\Module\QSL\CallForPrice\View\ItemsList\Product\Customer;

/**
 * Decorated Product List widget.
 */
abstract class ACustomer extends \XLite\View\ItemsList\Product\Customer\ACustomerAbstract
    implements \XLite\Base\IDecorator
{
    /**
     * Get a list of CSS files required to display the widget properly
     *
     * @return array
     */
    public function getCSSFiles()
    {
        $list = parent::getCSSFiles();

        $list[] = 'modules/QSL/CallForPrice/items_list/product/products_list.css';

        return $list;
    }

    /**
     * Get a list of JavaScript files required to display the widget properly
     *
     * @return array
     */
    public function getJSFiles()
    {
        $list = parent::getJSFiles();

        $list[] = 'modules/QSL/CallForPrice/items_list/product/disable_dragging.js';

        return $list;
    }

    /**
     * Return class attribute for the product cell
     *
     * @param \XLite\Model\Product $product The product to look for
     *
     * @return string
     */
    public function getProductCellClass(\XLite\Model\Product $product)
    {
        $classes = parent::getProductCellClass($product);

        if ($product->isCallForPrice()) {
            $classes .= ' call-for-price-product' . ($product->mustHaveVariants() ? ' call-for-price-variants' : '');
        }

        return $classes;
    }
    
    /**
     * Check if Add To Cart button should be visible for the product.
     *
     * @param \XLite\Model\Product $product The product to check
     *
     * @return string
     */
    protected function isAddToCartButtonVisible(\XLite\Model\Product $product)
    {
        return !$product->isCallForPrice();
    }

}
