<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * X-Cart
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the software license agreement
 * that is bundled with this package in the file LICENSE.txt.
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to licensing@x-cart.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not modify this file if you wish to upgrade X-Cart to newer versions
 * in the future. If you wish to customize X-Cart for your needs please
 * refer to http://www.x-cart.com/ for more information.
 *
 * @category  X-Cart 5
 * @author    Qualiteam software Ltd <info@x-cart.com>
 * @copyright Copyright (c) 2011-2013 Qualiteam software Ltd <info@x-cart.com>. All rights reserved
 * @link      http://www.x-cart.com/
 */

namespace XLite\Module\QSL\CallForPrice\View\Model;

use XLite\Module\QSL\CallForPrice\View\FormField\Select\AvailableForSale;

/**
 * Decorated product model widget.
 */
abstract class Product extends \XLite\View\Model\ProductAbstract implements \XLite\Base\IDecorator
{
    /**
     * Constructor
     *
     * @param array $params
     * @param array $sections
     */
    public function __construct(array $params = array(), array $sections = array())
    {
        parent::__construct($params, $sections);

        if (isset($this->schemaDefault['enabled'][static::SCHEMA_CLASS])) {
            $this->schemaDefault['enabled'][static::SCHEMA_CLASS] = 'XLite\Module\QSL\CallForPrice\View\FormField\Select\AvailableForSale';
        }
    }

    /**
     * Retrieve property from the model object.
     *
     * @param mixed $name Field/property name
     *
     * @return mixed
     */
    protected function getModelObjectValue($name)
    {
        $value = parent::getModelObjectValue($name);

        if ('enabled' == $name) {
            // Combine enabled and callFormPrice properties into a single "Enabled" dropdown field
            $callForPrice = parent::getModelObjectValue('callForPrice');
            if ($callForPrice && $value) {
                $value = AvailableForSale::CALL;
            } else {
                $value = $value ? AvailableForSale::YES : AvailableForSale::NO;
            }
        }

        return $value;
    }

    /**
     * Populate model object properties by the passed data
     *
     * @param array $data Data to set
     *
     * @return void
     */
    protected function setModelProperties(array $data)
    {
        // Split the single "Enabled" dropdown into separate enabled and callForPrice product properties
        if (isset($data['enabled'])) {
            if ((AvailableForSale::CALL === $data['enabled'])) {
                $data['callForPrice'] = true;
                $data['enabled'] = true;
            } else {
                $data['callForPrice'] = false;
                $data['enabled'] = (AvailableForSale::YES === $data['enabled']);
            }
        }

        parent::setModelProperties($data);
    }
}
