<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * X-Cart
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the software license agreement
 * that is bundled with this package in the file LICENSE.txt.
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to licensing@x-cart.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not modify this file if you wish to upgrade X-Cart to newer versions
 * in the future. If you wish to customize X-Cart for your needs please
 * refer to http://www.x-cart.com/ for more information.
 *
 * @category  X-Cart 5
 * @author    Qualiteam software Ltd <info@x-cart.com>
 * @copyright Copyright (c) 2011-2014 Qualiteam software Ltd <info@x-cart.com>. All rights reserved
 * @link      http://www.x-cart.com/
 */

namespace XLite\Module\QSL\CallForPrice\View;

/**
 * Product page widgets collection
 */
abstract class ProductPageCollection extends \XLite\View\ProductPageCollectionAbstract implements \XLite\Base\IDecorator
{
    /**
     * @inherit
     *
     * @return array
     */
    public function getWidgetsCollection()
    {
        // There is a lot of modules that decorate isAllowedWidget() method
        // and we can't override their rules in a simple way.
        //
        // So, instead of creating a ton of files with @LC_Dependencies tag,
        // we hack into this method and add all the necessary widgets manually.

        $list = parent::getWidgetsCollection();

        if ($this->getProduct()->isCallForPrice()) {
            foreach ($this->getCallForPriceWidgets() as $name) {
                if (!in_array($name, $list)) {
                    $list[] = $name;
                }
            }
        }

        return $list;
    }

    /**
     * @inherit
     *
     * @return array
     */
    protected function defineWidgetsCollection()
    {
        return array_merge(
            parent::defineWidgetsCollection(),
            array(
                '\XLite\Module\QSL\CallForPrice\View\CallForPrice',
            )
        );
    }

    /**
     * Returns class names of widgets on the product page which should be reloaded
     * every time the widget collection refreshes.
     *
     * @return array
     */
    protected function getCallForPriceWidgets()
    {
        $result = array();
        
        $list = array(
            '\XLite\View\Price',
            '\XLite\Module\CDev\Wholesale\View\ProductPrice',
            '\XLite\View\Product\Details\Customer\Quantity',
            '\XLite\View\Product\Details\Customer\AddButton',
            '\XLite\Module\CDev\Paypal\View\Button\Product\ExpressCheckout',
        );
        
        foreach ($list as $className) {
            if (\XLite\Core\Operator::isClassExists($className)) {
                $result[] = $className;
            }
        }
        
        return $result;
    }

}
